@@ -4,9 +4,6 @@ use strict;
 use warnings;
 use DynaLoader;
 
-# Make sure debugging with Data::Dumper is more easily comparable:
-$Data::Dumper::Sortkeys = 1;
-
 # different files, but same package
 # require them here to avoid dependencies
 use URPM::Build;
@@ -14,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = 'v5.225';
+our $VERSION = 'v5.23';
 
 URPM->bootstrap($VERSION);
 
@@ -293,7 +290,7 @@ URPM - Manipulate RPM files and headers
     });
 
     # loading and parsing a synthesis file
-    my $urpm = URPM->new;
+    my $urpm = new URPM;
     $urpm->parse_synthesis("synthesis.sample.cz");
     $urpm->traverse(sub {
 	# retrieve all packages from the dependency list
@@ -353,9 +350,6 @@ Force the re-reading of the RPM configuration files.
 $urpm->{depslist} is loaded when parsing sources (synthesis, hdlists or a plain
 rpm file).
 
-Synthesis and hdlists files are generated by L<genhdlist2> or L<gendistrib> (a
-gendhlist2 wrapper handling a whole media set) from L<rpmtools> package.
-
 =over
 
 =item $urpm->parse_synthesis($file [, callback => sub {...} ])
@@ -843,11 +837,6 @@ Options are:
     update => 0 / 1 : indicates whether this is an upgrade
     excludepath => [ ... ]
 
-=item $trans->addReinstall($pkg)
-
-Adds a package to be re-installed to the transaction represented by $trans.
-$pkg is an C<URPM::Package> object.
-
 =item $trans->remove($name)
 
 Adds a package to be erased to the transaction represented by $trans.
